@@ -565,7 +565,7 @@ class Cursor(DBAPICursor):
         explain_analyze_response = self.connection.client.explainAnalyze(explain_analyze_request)
         return dict(
             is_cached=explain_analyze_response.isCached,
-            persing_time=explain_analyze_response.parsingTime,
+            parsing_time=explain_analyze_response.parsingTime,
             queuing_time=explain_analyze_response.queueingTime,
             planner=explain_analyze_response.explainAnalyze,
         )
